@@ -1,8 +1,10 @@
+from __future__ import absolute_import, print_function
+
 from tweepy.streaming import StreamListener
 from tweepy import OAuthHandler
 from tweepy import Stream
 
-# Go to http://dev.twitter.com and create an app.
+# Go to http://apps.twitter.com and create an app.
 # The consumer key and secret will be generated for you after
 consumer_key=""
 consumer_secret=""
@@ -13,16 +15,16 @@ access_token=""
 access_token_secret=""
 
 class StdOutListener(StreamListener):
-    """ A listener handles tweets are the received from the stream.
+    """ A listener handles tweets that are received from the stream.
     This is a basic listener that just prints received tweets to stdout.
 
     """
     def on_data(self, data):
-        print data
+        print(data)
         return True
 
     def on_error(self, status):
-        print status
+        print(status)
 
 if __name__ == '__main__':
     l = StdOutListener()
