@@ -2,9 +2,12 @@
 # Copyright 2009-2010 Joshua Roesslein
 # See LICENSE for details.
 
+from __future__ import print_function
+
 from tweepy.error import TweepError
 from tweepy.parsers import ModelParser, RawParser
 
+
 class Cursor(object):
     """Pagination helper class"""
 
@@ -33,6 +36,7 @@ class Cursor(object):
         i.limit = limit
         return i
 
+
 class BaseIterator(object):
 
     def __init__(self, method, args, kargs):
@@ -41,6 +45,9 @@ class BaseIterator(object):
         self.kargs = kargs
         self.limit = 0
 
+    def __next__(self):
+        return self.next()
+
     def next(self):
         raise NotImplementedError
 
@@ -50,6 +57,7 @@ class BaseIterator(object):
     def __iter__(self):
         return self
 
+
 class CursorIterator(BaseIterator):
 
     def __init__(self, method, args, kargs):
@@ -62,9 +70,9 @@ class CursorIterator(BaseIterator):
     def next(self):
         if self.next_cursor == 0 or (self.limit and self.num_tweets == self.limit):
             raise StopIteration
-        data, cursors = self.method(
-                cursor=self.next_cursor, *self.args, **self.kargs
-        )
+        data, cursors = self.method(cursor=self.next_cursor,
+                                    *self.args,
+                                    **self.kargs)
         self.prev_cursor, self.next_cursor = cursors
         if len(data) == 0:
             raise StopIteration
@@ -74,17 +82,18 @@ class CursorIterator(BaseIterator):
     def prev(self):
         if self.prev_cursor == 0:
             raise TweepError('Can not page back more, at first page')
-        data, self.next_cursor, self.prev_cursor = self.method(
-                cursor=self.prev_cursor, *self.args, **self.kargs
-        )
+        data, self.next_cursor, self.prev_cursor = self.method(cursor=self.prev_cursor,
+                                                               *self.args,
+                                                               **self.kargs)
         self.num_tweets -= 1
         return data
 
+
 class IdIterator(BaseIterator):
 
     def __init__(self, method, args, kargs):
         BaseIterator.__init__(self, method, args, kargs)
-        self.max_id = kargs.get('max_id')
+        self.max_id = kargs.pop('max_id', None)
         self.num_tweets = 0
         self.results = []
         self.model_results = []
@@ -98,17 +107,20 @@ class IdIterator(BaseIterator):
         if self.index >= len(self.results) - 1:
             data = self.method(max_id=self.max_id, parser=RawParser(), *self.args, **self.kargs)
 
-            old_parser = self.method.__self__.parser
-            # Hack for models which expect ModelParser to be set
-            self.method.__self__.parser = ModelParser()
+            if hasattr(self.method, '__self__'):
+                old_parser = self.method.__self__.parser
+                # Hack for models which expect ModelParser to be set
+                self.method.__self__.parser = ModelParser()
 
             # This is a special invocation that returns the underlying
             # APIMethod class
             model = ModelParser().parse(self.method(create=True), data)
-            self.method.__self__.parser = old_parser
+            if hasattr(self.method, '__self__'):
+                self.method.__self__.parser = old_parser
+                result = self.method.__self__.parser.parse(self.method(create=True), data)
+            else:
+                result = model
 
-            result = self.method.__self__.parser.parse(self.method(create=True), data)
-            
             if len(self.results) != 0:
                 self.index += 1
             self.results.append(result)
@@ -117,12 +129,12 @@ class IdIterator(BaseIterator):
             self.index += 1
             result = self.results[self.index]
             model = self.model_results[self.index]
-            
+
         if len(result) == 0:
             raise StopIteration
         # TODO: Make this not dependant on the parser making max_id and
         # since_id available
-        self.max_id = model.max_id 
+        self.max_id = model.max_id
         self.num_tweets += 1
         return result
 
@@ -142,6 +154,7 @@ class IdIterator(BaseIterator):
         self.num_tweets += 1
         return data
 
+
 class PageIterator(BaseIterator):
 
     def __init__(self, method, args, kargs):
@@ -149,8 +162,9 @@ class PageIterator(BaseIterator):
         self.current_page = 0
 
     def next(self):
-        if self.limit > 0 and self.current_page > self.limit:
-            raise StopIteration
+        if self.limit > 0:
+            if self.current_page > self.limit:
+                raise StopIteration
 
         items = self.method(page=self.current_page, *self.args, **self.kargs)
         if len(items) == 0:
@@ -159,11 +173,12 @@ class PageIterator(BaseIterator):
         return items
 
     def prev(self):
-        if (self.current_page == 1):
+        if self.current_page == 1:
             raise TweepError('Can not page back more, at first page')
         self.current_page -= 1
         return self.method(page=self.current_page, *self.args, **self.kargs)
 
+
 class ItemIterator(BaseIterator):
 
     def __init__(self, page_iterator):
@@ -174,8 +189,9 @@ class ItemIterator(BaseIterator):
         self.num_tweets = 0
 
     def next(self):
-        if self.limit > 0 and self.num_tweets == self.limit:
-            raise StopIteration
+        if self.limit > 0:
+            if self.num_tweets == self.limit:
+                raise StopIteration
         if self.current_page is None or self.page_index == len(self.current_page) - 1:
             # Reached end of current page, get the next page...
             self.current_page = self.page_iterator.next()
@@ -196,4 +212,3 @@ class ItemIterator(BaseIterator):
         self.page_index -= 1
         self.num_tweets -= 1
         return self.current_page[self.page_index]
-
